Method: Jenkins::Slaves::ComputerListener#prelaunch

Defined in:
lib/jenkins/slaves/computer_listener.rb

#prelaunch(computer, listener) ⇒ Object

Called before a ComputerLauncher is asked to launch a connection with Computer.

This enables you to do some configurable checks to see if we want to bring this slave online or if there are considerations that would keep us from doing so.

Calling Computer#abort would let you veto the launch operation. Other thrown exceptions will also have the same effect

Parameters:

  • computer (Jenkins::Model::Computer)

    the computer about to be launched

  • listener (Jenkins::Model::Listener)

    the listener connected to the slave console log.



37
38
# File 'lib/jenkins/slaves/computer_listener.rb', line 37

def prelaunch(computer, listener)
end